# Author : BetaCodings
# Author : info@betacodings.com
# Maintainer By: Emmanuel Martins
# Maintainer Email: emmamartinscm@gmail.com
# Created by BetaCodings on 16/01/2020.
from pytonik import Version
import os
lang = {}

lang['bg_BG']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT :
            'Добре дошли в Pytonik MVC Framework %s Стартиране на файловата структура.'% Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : "Моля, въведете или 'r' или 'н'.",
		"Please enter some text." : "Моля, въведете малко текст",
		'Please enter a valid path name.' : "Моля, въведете валидно име на пътя.",
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'За повече информация посетете  < https://pytonik.readthedocs.io >.',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """Pytonik е рамка на python, създадена за подобряване на уеб развитието
         бързо и лесно, също така помогнете на уеб разработчиците да създадат повече приложения с по-малко кодове.
         той използва експресивен архитектурен модел, структуриран върху контролера за изглед на модел MVC
         и пакети от компоненти, които да се използват повторно, докато разгръщат рамката.""",
		'Please enter values for the following settings.' : 'Моля, въведете стойности за следните настройки.',
        'Selected root path: %s' % os.getcwd() : 'Избран корен път: %s' % os.getcwd() ,
        'Do you want to create file pytonik in this directory  (y/n)' : 'Искате ли да създадете файл pytonik в тази директория (г / н)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Въведете име на проекта, той ще бъде използван при създаването на папки на проекти, избягвайте място, докато пишете',
        'Project name' : 'Име на проекта',
        'Project In-progress, please wait..' : 'Изпълнение на проекта, моля изчакайте..',
        'Do you want to quit (y/n)' : 'Искате ли да прекратите (y / n)'
	 }
	


lang['cs_CZ']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Vítejte v Pytonik MVC Framework %s Start File Structure.'% Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : "Zadejte buď 'y' nebo 'n'",
		"Please enter some text." : 'Zadejte nějaký text.',
		'Please enter a valid path name.' : 'Zadejte platný název cesty.',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Pro více informací navštivte < https://pytonik.readthedocs.io >.',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """Pytonik je pythonový rámec vytvořený pro zlepšení vývoje webu
         rychlé a snadné a také vývojářům webových stránek pomáhají vytvářet více aplikací s menším počtem kódů.
         používá expresivní architektonický vzor, strukturovaný na řadiči zobrazení modelu MVC
         a svazky součástí k opětovnému použití při nasazení rámce""",
		'Please enter values for the following settings.' : 'Zadejte hodnoty pro následující nastavení.',
        'Selected root path: %s' % os.getcwd() : 'Vybraná kořenová cesta: %s' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Chcete v tomto adresáři vytvořit soubor pytonik (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Zadejte název projektu, použije se při vytváření složky projektu, při psaní se vyhýbejte mezerám',
        'Project name' : 'Název projektu',
        'Project In-progress, please wait..' : 'Probíhá projekt, počkejte prosím..',
        'Do you want to quit (y/n)' : 'Chcete skončit (y / n)'
	 }


lang['da_DK']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Velkommen til Pytonik MVC Framework %s Start filstruktur.' % Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : "Indtast enten 'y' eller 'n'.",
		"Please enter some text." : 'Indtast venligst noget tekst.',
		'Please enter a valid path name.' : 'Indtast et gyldigt stienavn.',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'For mere information, besøg < https://pytonik.readthedocs.io >.',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """Pytonik er en pythonramme bygget til at forbedre webudvikling
         hurtigt og nemt, hjælpe også webudviklere med at bygge flere apps med mindre koder.
         det bruger et ekspressivt arkitektonisk mønster, struktureret på MVC-modellen til modelvisning
         og bundter af komponent, der skal genbruges, mens rammen implementeres""",
		'Please enter values for the following settings.' : 'Indtast værdier for følgende indstillinger.',
        'Selected root path: %s' % os.getcwd() : 'Valgt rodsti: %s' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Vil du oprette fil pytonik i dette bibliotek (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Angiv projektnavn, det vil blive brugt i oprettelse af projektmappe, undgå plads, mens du skriver',
        'Project name' : 'Projekt navn',
        'Project In-progress, please wait..' : 'Projekt i gang, vent venligst ..',
        'Do you want to quit (y/n)' : 'Vil du afslutte (å / n)'
	 }




lang['de_DE']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Willkommen beim Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : "Bitte geben Sie entweder 'y' oder 'n' ein.",
		"Please enter some text." : 'Bitte geben Sie einen Text ein.',
		'Please enter a valid path name.' : 'Bitte geben Sie einen gültigen Pfadnamen ein.',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Für weitere Informationen besuchen Sie < https://pytonik.readthedocs.io >.',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Pytonik ist ein Python-Framework zur Verbesserung der Webentwicklung
         Helfen Sie Webentwicklern außerdem, schnell und einfach mehr Apps mit weniger Codes zu erstellen.
         Es verwendet ein ausdrucksstarkes Architekturmuster, das auf dem Model View Controller MVC strukturiert ist
         und Bündel von Komponenten, die beim Bereitstellen des Frameworks wiederverwendet werden sollen.
         """,
		'Please enter values for the following settings.' : 'Bitte geben Sie Werte für die folgenden Einstellungen ein.',
        'Selected root path: %s' % os.getcwd() : 'Ausgewählter Stammpfad: %s' % os.getcwd() ,
        'Do you want to create file pytonik in this directory  (y/n)' : 'Wollen Sie die Datei pytonik in diesem Verzeichnis erstellen (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Geben Sie den Projektnamen an, der bei der Erstellung des Projektordners verwendet werden soll. Vermeiden Sie Leerzeichen bei der Eingabe',
        'Project name' : 'Projektname',
        'Project In-progress, please wait..' : 'Projekt in Bearbeitung, bitte warten ..',
        'Do you want to quit (y/n)' : 'Möchtest du kündigen (j / n)'
	 }


lang['el_GR']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Καλώς ήρθατε στο Pytonik MVC Framework %s Start Αρχείο Δομή' % Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : "Πληκτρολογήστε είτε 'και' είτε 'n'.",
		"Please enter some text." : 'Εισαγάγετε κάποιο κείμενο',
		'Please enter a valid path name.' : 'Εισαγάγετε ένα έγκυρο όνομα διαδρομής.',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Για περισσότερες πληροφορίες, επισκεφθείτε < https://pytonik.readthedocs.io >.',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Το Pytonik είναι ένα πλαίσιο Python που δημιουργήθηκε για να ενισχύσει την ανάπτυξη ιστού
         γρήγορη και εύκολη, βοηθούν επίσης τους προγραμματιστές ιστού να δημιουργήσουν περισσότερες εφαρμογές με λιγότερους κωδικούς.
         χρησιμοποιεί εκφραστικό αρχιτεκτονικό μοτίβο, δομημένο σε ελεγκτή προβολής μοντέλου MVC
         και δέσμες στοιχείων για επαναχρησιμοποίηση κατά την ανάπτυξη του πλαισίου.
         """,
		'Please enter values for the following settings.' : 'Εισαγάγετε τιμές για τις ακόλουθες ρυθμίσεις.',
        'Selected root path: %s' % os.getcwd() : 'Επιλεγμένη ρίζα διαδρομής: %s ' % os.getcwd() ,
        'Do you want to create file pytonik in this directory  (y/n)' : 'Θέλετε να δημιουργήσετε αρχείο pytonik σε αυτόν τον κατάλογο (και / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Παρέχετε το όνομα του έργου, θα χρησιμοποιηθεί στη δημιουργία φακέλου έργου, θα αποφύγετε χώρο κατά την πληκτρολόγηση',
        'Project name' : 'Όνομα έργου',
        'Project In-progress, please wait..' : 'Έργο σε εξέλιξη, παρακαλώ περιμένετε ..',
        'Do you want to quit (y/n)' : 'Θέλετε να τερματίσετε (y / n)'
	 }


lang['es_ES']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Bienvenido a la estructura del archivo de inicio de Pytonik MVC Framework %s' % Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : "Por favor ingrese 'y' o 'n'.",
		"Please enter some text." : 'Por favor ingrese un texto.',
		'Please enter a valid path name.' : 'Por favor, introduzca un nombre de ruta válido.',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Para más información visite < https://pytonik.readthedocs.io >. ',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Pytonik es un marco de Python creado para mejorar el desarrollo web
         rápido y fácil, también ayuda a los desarrolladores web a crear más aplicaciones con menos códigos.
         utiliza un patrón arquitctónico expresivo, estructurado en el controlador de vista de modelo MVC
         y paquetes de componentes para reutilizar mientras se implementa el marco.
         """,
		'Please enter values for the following settings.' : 'Ingrese valores para las siguientes configuraciones.',
        'Selected root path: %s' % os.getcwd() : 'Ruta raíz seleccionada: %s'% os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : '¿Desea crear el archivo pytonik en este directorio (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Proporcione el nombre del proyecto, se usará en la creación de la carpeta del proyecto, evite el espacio mientras escribe',
        'Project name' : 'Nombre del proyecto',
        'Project In-progress, please wait..' : 'Proyecto en curso, por favor espere ..',
        'Do you want to quit (y/n)' : '¿Quieres dejar de fumar (sí / no)'
	 }


lang['et_EE']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Tere tulemast Pytoniku MVC Framework %s faili algstruktuuri.' % Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : 'Sisestage kas "y" või "n".',
		"Please enter some text." : 'Palun sisestage mõni tekst.',
		'Please enter a valid path name.' : 'Sisestage kehtiv tee nimi',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Lisateavet leiate aadressilt <https://pytonik.readthedocs.io>.',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Pytonik on pythoni raamistik, mis on loodud veebiarenduse tõhustamiseks
         kiire ja lihtne, aitab ka veebiarendajatel luua rohkem vähem koodidega rakendusi.
         see kasutab ekspressiivset arhitektuurimustrit, mis on üles ehitatud mudeli vaatekontrollerile MVC
         ja komponentide kimbud raamistiku juurutamise ajal taaskasutamiseks.
         """,
		'Please enter values for the following settings.' : 'Sisestage järgmiste sätete väärtused.',
        'Selected root path: %s' % os.getcwd() : 'Valitud juuritee: %s' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Kas soovite selles kataloogis luua faili pytonik (jah / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Esitage projekti nimi, seda kasutatakse projekti kaustade loomisel, vältige tühja teksti sisestamise ajal ruumi',
        'Project name' : 'Projekti nimi',
        'Project In-progress, please wait..' : 'Projekt on pooleli, palun oodake ..',
        'Do you want to quit (y/n)' : 'Kas soovite väljuda (jah / n)'
	 }



lang['fi_FI']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Tervetuloa Pytonik MVC Framework %s : n aloitustiedostorakenteeseen.'% Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : "Kirjoita joko 'y' tai 'n'.",
		"Please enter some text." : 'Anna teksti.',
		'Please enter a valid path name.' : 'Anna kelvollinen polun nimi',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Lisätietoja on osoitteessa <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Pytonik on python-kehys, joka on rakennettu parantamaan web-kehitystä
         nopea ja helppo, auta myös web-kehittäjiä rakentamaan enemmän sovelluksia vähemmän koodeilla.
         se käyttää ilmaisullista arkkitehtikuviota, joka on rakennettu mallinäkymän ohjaimeen MVC
         ja komponenttipaketit uudelleenkäyttöön, kun kehys otetaan käyttöön.
         """,
		'Please enter values for the following settings.' : 'Anna seuraavien asetusten arvot.',
        'Selected root path: %s' % os.getcwd() : 'Valittu pääpolku: %s' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Haluatko luoda pytonik-tiedoston tähän hakemistoon (ky / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Anna projektin nimi, sitä käytetään projektikansioiden luonnissa. Vältä tilaa kirjoittaessasi',
        'Project name' : 'Projektin nimi',
        'Project In-progress, please wait..' : 'Projekti kesken, odota ..',
        'Do you want to quit (y/n)' : 'Haluatko lopettaa (y / n)'
	 }


lang['fr_FR']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Bienvenue dans la structure du fichier de démarrage Pytonik MVC Framework 1233.',
		"Please enter either 'y' or 'n'." : 'Veuillez saisir «y» ou «n».',
		"Please enter some text." : 'Veuillez saisir du texte.',
		'Please enter a valid path name.' : "Veuillez saisir un nom de chemin valide",
		'For more information, visit < https://pytonik.readthedocs.io >.' : "Pour plus d'informations, visitez <https://pytonik.readthedocs.io>",
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Pytonik est un framework python conçu pour améliorer le développement web
         rapide et facile, aide également les développeurs Web à créer plus d'applications avec moins de codes.
         il utilise un modèle architectural expressif, structuré sur le contrôleur de vue du modèle MVC
         et des lots de composants à réutiliser lors du déploiement du framework.
         """,
		'Please enter values for the following settings.' : 'Veuillez saisir des valeurs pour les paramètres suivants.',
        'Selected root path: %s' % os.getcwd() : 'Chemin racine sélectionné: %s' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Voulez-vous créer le fichier pytonik dans ce répertoire (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : "Fournissez le nom du projet, il sera utilisé dans la création du dossier de projet, évitez l'espace lors de la frappe",
        'Project name' : 'Nom du projet',
        'Project In-progress, please wait..' : 'Projet en cours, veuillez patienter ..',
        'Do you want to quit (y/n)' : 'Voulez-vous quitter (o / n)'
	 }


lang['hr_HR']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Dobrodošli u početnu strukturu datoteke Pytonik MVC Framework 1233.',
		"Please enter either 'y' or 'n'." : 'Unesite ili y ili n.',
		"Please enter some text." : 'Unesite neki tekst.',
		'Please enter a valid path name.' : 'Unesite valjano ime staze.',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Za više informacija posjetite <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Pytonik je python-ov okvir izgrađen za unapređenje web-razvoja
         brzo i jednostavno, također pomažite web programerima da izrade više aplikacija s manje kodova.
         koristi izražajni arhitektonski uzorak strukturiran na modelu kontrolera MVC
         i pakete komponenti za ponovnu upotrebu tijekom raspoređivanja okvira.
         """,
		'Please enter values for the following settings.' : 'Unesite vrijednosti za sljedeće postavke.',
        'Selected root path: %s' % os.getcwd() : 'Odabrani korijenski put: %s' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Želite li stvoriti datoteku pytonik u ovom direktoriju (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Unesite naziv projekta, on će se koristiti u izradi mapa projekta, izbjegavajte razmak dok tipkate',
        'Project name' : 'Naziv projekta',
        'Project In-progress, please wait..' : 'U tijeku je projekt, pričekajte ..',
        'Do you want to quit (y/n)' : 'Želite li prekinuti (y / n)'
	 }


lang['hu_HU']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Üdvözöljük a Pytonik MVC Framework 1233 Start fájlszerkezetében.',
		"Please enter either 'y' or 'n'." : 'Kérjük, írja be az "y" vagy "n" értéket.',
		"Please enter some text." : 'Kérjük, írjon be egy szöveget.',
		'Please enter a valid path name.' : 'Adjon meg egy érvényes elérési utat',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'További információ: <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : 'Bulgarian',
		'Please enter values for the following settings.' : """A Pytonik egy python keretrendszer, amelyet a webfejlesztés fokozására fejlesztettek ki
         gyors és egyszerű, és segít a webfejlesztőknek több alkalmazás létrehozásában kevesebb kóddal.
         kifejező építészeti mintát használ, az MVC modellnéző vezérlőjén felépítve
         és az összetevők kötegei a keret telepítése közben történő újrafelhasználáshoz.""",
        'Selected root path: %s' % os.getcwd() : 'Kiválasztott gyökérút: %s'% os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'A pytonik fájlt szeretné létrehozni ebben a könyvtárban (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : "Adja meg a projekt nevét, ez felhasználásra kerül a projekt mappák létrehozásában, kerülje el a helyet gépelés közben",
        'Project name' : 'Projekt neve',
        'Project In-progress, please wait..' : 'Folyamatban lévő projekt, kérem várjon ..',
        'Do you want to quit (y/n)' : 'Szeretne kilépni (y / n)'
	 }

lang['it_IT']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Benvenuti nella struttura dei file di avvio di Pytonik MVC Framework %s .'% Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : "Inserisci 'y' o 'n'.",
		"Please enter some text." : 'Per favore, inserisci del testo.',
		'Please enter a valid path name.' : 'Inserisci un nome percorso valido',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Per ulteriori informazioni, visitare <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Pytonik è un framework Python creato per migliorare lo sviluppo web
         facile e veloce, aiuta anche gli sviluppatori Web a creare più app con meno codici.
         utilizza un modello architettonico espressivo, strutturato sul controller della vista modello MVC
         e fasci di componenti da riutilizzare durante la distribuzione del framework.
         """,
		'Please enter values for the following settings.' : "Inserisci i valori per le seguenti impostazioni.",
        'Selected root path: %s' % os.getcwd() : 'Percorso radice selezionato: %s' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Vuoi creare il file pytonik in questa directory (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Fornire il nome del progetto, verrà utilizzato nella creazione della cartella del progetto, evitare lo spazio durante la digitazione',
        'Project name' : 'Nome del progetto',
        'Project In-progress, please wait..' : 'Progetto in corso, attendere ..',
        'Do you want to quit (y/n)' : 'Vuoi uscire (sì / no)'
	 }


lang['lt_LT']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : '',
		"Please enter either 'y' or 'n'." : 'Įveskite „y“ arba „n“.',
		"Please enter some text." : '',
		'Please enter a valid path name.' : '',
		'For more information, visit < https://pytonik.readthedocs.io >.' : '',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : 'Bulgarian',
		'Please enter values for the following settings.' : '',
        'Selected root path: %s' % os.getcwd() : '',
        'Do you want to create file pytonik in this directory  (y/n)' : '',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : '',
        'Project name' : '',
        'Project In-progress, please wait..' : '',
        'Do you want to quit (y/n)' : ''
	 }



lang['lt_LT']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Sveiki atvykę į „Pytonik MVC Framework %s Start File Struktūra“.'% Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : '',
		"Please enter some text." : 'Įveskite šiek tiek teksto.',
		'Please enter a valid path name.' : 'Įveskite teisingą kelio pavadinimą',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Norėdami gauti daugiau informacijos, apsilankykite <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        „Pytonik“ yra python'o sistema, sukurta interneto plėtrai skatinti
         greitas ir lengvas, taip pat padėkite žiniatinklio kūrėjams sukurti daugiau programų su mažiau kodų.
         jis naudoja išraiškingą architektūros modelį, struktūruotą modelio peržiūros valdiklyje MVC
         ir komponentų paketai pakartotiniam naudojimui diegiant sistemą.
         """,
		'Please enter values for the following settings.' : 'Įveskite šių parametrų reikšmes.',
        'Selected root path: %s' % os.getcwd() : 'Pasirinktas šaknies kelias: %s' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Ar norite sukurti katalogą failą pytonik (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Pateikite projekto pavadinimą, jis bus naudojamas kuriant projekto aplanką, rašydami venkite vietos',
        'Project name' : 'Projekto pavadinimas',
        'Project In-progress, please wait..' : 'Vykdomas projektas, palaukite ..',
        'Do you want to quit (y/n)' : 'Ar norite mesti (y / n)'
	 }




lang['lv_LV']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Laipni lūdzam Pytonik MVC Framework %s sākuma faila struktūrā.'% Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : 'Lūdzu, ievadiet “y” vai “n”.',
		"Please enter some text." : 'Lūdzu, ievadiet tekstu.',
		'Please enter a valid path name.' : 'Lūdzu, ievadiet derīgu ceļa nosaukumu',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Lai iegūtu papildinformāciju, apmeklējiet vietni <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Pytonik ir python ietvars, kas izveidots, lai uzlabotu tīmekļa attīstību
         ātri un viegli, palīdziet arī tīmekļa izstrādātājiem izveidot vairāk lietotņu ar mazāku kodu daudzumu.
         tas izmanto izteiksmīgu arhitektūras modeli, kas strukturēts uz modeļa skatu kontroliera MVC
         un komponentu saišķus atkārtotai izmantošanai, izvietojot ietvaru.
         """,
		'Please enter values for the following settings.' : 'Lūdzu, ievadiet šo iestatījumu vērtības.',
        'Selected root path: %s' % os.getcwd() : 'Atlasītais saknes ceļš: %s'% os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Vai vēlaties šajā direktorijā izveidot failu pytonik (jā / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Norādiet projekta nosaukumu, tas tiks izmantots projekta mapes izveidē, mašīnrakstīšanas laikā izvairieties no vietas',
        'Project name' : 'Projekta nosaukums',
        'Project In-progress, please wait..' : 'Projekts notiek, lūdzu, uzgaidiet ..',
        'Do you want to quit (y/n)' : 'Vai vēlaties atmest (jā / n)'
	 }



lang['nl_NL']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Welkom bij de Pytonik MVC Framework %s Start bestandsstructuur.'% Version.VERSION_TEXT ,
		"Please enter either 'y' or 'n'." : "Voer 'y' of 'n' in.",
		"Please enter some text." : 'Voer wat tekst in.',
		'Please enter a valid path name.' : 'Voer een geldige padnaam in',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Ga voor meer informatie naar <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Pytonik is een python-framework dat is gebouwd om webontwikkeling te verbeteren
         snel en gemakkelijk, ook helpen webontwikkelaars om meer apps met minder codes te bouwen.
         het maakt gebruik van een expressief architecturaal patroon, gestructureerd op MVC-modelcontroller
         en bundels van componenten om te hergebruiken terwijl het framework wordt geïmplementeerd.
        """,
		'Please enter values for the following settings.' : 'Voer waarden in voor de volgende instellingen.',
        'Selected root path: %s' % os.getcwd() : 'Geselecteerd rootpad: %s '% os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Wil je een bestand pytonik maken in deze map (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Geef de projectnaam op, deze wordt gebruikt bij het maken van de projectmap, vermijd ruimte tijdens het typen',
        'Project name' : 'Naam van het project',
        'Project In-progress, please wait..' : 'Project in uitvoering, even geduld aub ..',
        'Do you want to quit (y/n)' : 'Wilt u stoppen (j / n)'
	 }





lang['no_NO']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Velkommen til Pytonik MVC Framework %s Start filstruktur.'% Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : "Skriv inn enten 'y' eller 'n'.",
		"Please enter some text." : 'Skriv inn litt tekst.',
		'Please enter a valid path name.' : 'Vennligst tast inn et gyldig banenavn',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'For mer informasjon, besøk <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Pytonik er et python-rammeverk bygget for å forbedre webutvikling
         raskt og enkelt, også hjelpe nettutviklere med å bygge flere apper med mindre koder.
         den bruker ekspressivt arkitektonisk mønster, strukturert på modellvisningskontrolleren MVC
         og bunter med komponent for å gjenbruke mens du distribuerer rammen.""",
		'Please enter values for the following settings.' : 'Angi verdier for følgende innstillinger.',
        'Selected root path: %s' % os.getcwd() : 'Valgt rotsti: %s' %os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Vil du opprette fil pytonik i denne katalogen (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Oppgi prosjektnavn, det vil bli brukt i opprettelse av prosjektmapper, unngå plass mens du skriver',
        'Project name' : 'Prosjektnavn',
        'Project In-progress, please wait..' : 'Prosjekt pågår, vennligst vent ..',
        'Do you want to quit (y/n)' : 'Vil du slutte (å / n)'
	 }


lang['pl_PL']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Witamy w Pytonik MVC Framework %s Start Struktura plików.'% Version.VERSION_TEXT ,
		"Please enter either 'y' or 'n'." : 'Wpisz „y” lub „n”.',
		"Please enter some text." : 'Proszę podać tekst.',
		'Please enter a valid path name.' : 'Wpisz prawidłową nazwę ścieżki',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Aby uzyskać więcej informacji, odwiedź <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """Pytonik to framework Pythona zbudowany w celu usprawnienia tworzenia stron internetowych
         szybkie i łatwe, pomagają również twórcom stron internetowych w tworzeniu większej liczby aplikacji z mniejszą liczbą kodów.
         wykorzystuje ekspresyjny wzór architektoniczny, zbudowany na kontrolerze widoku modelu MVC
         oraz pakiety komponentów do ponownego wykorzystania podczas wdrażania frameworka.""",
		'Please enter values for the following settings.' : '',
        'Selected root path: %s' % os.getcwd() : 'Wybrana ścieżka katalogu głównego: %s ' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Czy chcesz utworzyć plik pytonik w tym katalogu (t / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Podaj nazwę projektu, będzie on używany podczas tworzenia folderu projektu, unikaj spacji podczas pisania',
        'Project name' : 'Nazwa Projektu',
        'Project In-progress, please wait..' : 'Projekt w toku, proszę czekać ..',
        'Do you want to quit (y/n)' : 'Czy chcesz rzucić palenie (t / n)'
	 }



lang['pt_PT']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Bem-vindo à estrutura do arquivo inicial do Pytonik MVC Framework %s .'% Version.VERSION_TEXT ,
		"Please enter either 'y' or 'n'." : '',
		"Please enter some text." : 'Digite algum texto.',
		'Please enter a valid path name.' : 'Digite um nome de caminho válido',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Para mais informações, visite <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """Pytonik é uma estrutura python criada para aprimorar o desenvolvimento da web
         rápido e fácil, também ajuda os desenvolvedores da Web a criar mais aplicativos com menos códigos.
         utiliza padrão arquitetural expressivo, estruturado no MVC do controlador de visualização de modelo
         e pacotes de componentes para reutilização durante a implantação da estrutura.""",
		'Please enter values for the following settings.' : 'Digite valores para as seguintes configurações.',
        'Selected root path: %s' % os.getcwd() : 'Caminho raiz selecionado: %s' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Deseja criar o arquivo pytonik neste diretório (s / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Forneça o nome do projeto, ele será usado na criação da pasta do projeto, evite espaço ao digitar',
        'Project name' : 'Nome do Projeto',
        'Project In-progress, please wait..' : 'Projeto em andamento, aguarde ..',
        'Do you want to quit (y/n)' : "Deseja sair (s / n)"
	 }






#Romanian
lang['ro_RO']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Bine ați venit la Pytonik MVC Framework %s Start Structura fișierelor.'% Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : 'Vă rugăm să introduceți „y” sau „n”.',
		"Please enter some text." : 'Vă rugăm să introduceți un text.',
		'Please enter a valid path name.' : 'Vă rugăm să introduceți un nume de cale valid',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Pentru mai multe informații, accesați <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Pytonik este un cadru python construit pentru a îmbunătăți dezvoltarea web
         rapid și ușor, ajutați și dezvoltatorii web să creeze mai multe aplicații cu mai puține coduri.
         folosește un model arhitectural expresiv, structurat pe controlerul de vedere model MVC
         și pachete de componente pentru a le reutiliza în timp ce implementați cadrul.""",
		'Please enter values for the following settings.' : 'Vă rugăm să introduceți valori pentru următoarele setări.',
        'Selected root path: %s' % os.getcwd() : 'Calea rădăcină selectată: %s'  % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Doriți să creați fișier pytonik în acest director (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Furnizați numele proiectului, acesta va fi utilizat în crearea folderului de proiect, pentru a evita spațiul în timp ce tastați',
        'Project name' : 'Denumirea proiectului',
        'Project In-progress, please wait..' : 'Proiect în curs, vă rugăm să așteptați ..',
        'Do you want to quit (y/n)' : "Doriți să renunțați (y / n)"
	 }



lang['ru_RU']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Добро пожаловать в структуру файлов запуска Pytonik MVC Framework %s.' % Version.VERSION_TEXT ,
		"Please enter either 'y' or 'n'." : 'Пожалуйста, введите "да" или "нет".',
		"Please enter some text." : 'Пожалуйста, введите текст.',
		'Please enter a valid path name.' : 'Пожалуйста, введите правильный путь',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Для получения дополнительной информации посетите <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """
        Pytonik - это среда разработки Python, созданная для улучшения веб-разработки.
         быстро и легко, а также помогает веб-разработчикам создавать больше приложений с меньшим количеством кодов.
         он использует выразительный архитектурный паттерн, структурированный на модельном контроллере MVC
         и комплекты компонентов для повторного использования при развертывании платформы.
         """,
		'Please enter values for the following settings.' : 'Пожалуйста, введите значения для следующих настроек.',
        'Selected root path: %s' % os.getcwd() : 'Выбранный корневой путь: %s' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Вы хотите создать файл pytonik в этом каталоге (да / нет)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Укажите имя проекта, оно будет использоваться при создании папки проекта, избегайте пробелов при наборе текста',
        'Project name' : 'Название проекта',
        'Project In-progress, please wait..' : 'Проект в процессе, пожалуйста, подождите ..',
        'Do you want to quit (y/n)' : 'Вы хотите выйти (да / нет)'
	 }



lang['sv_SE']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Välkommen till Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : "Ange antingen 'y' eller 'n'.",
		"Please enter some text." : 'Vänligen ange lite text.',
		'Please enter a valid path name.' : 'Ange ett giltigt sökvägsnamn',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Mer information finns på <https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """Pytonik är en pythonram som byggs för att förbättra webbutvecklingen
         snabbt och enkelt, hjälper också webbutvecklare att bygga fler appar med mindre koder.
         den använder ett uttrycksfullt arkitektoniskt mönster, strukturerat på modellvynkontrollen MVC
         och buntar med komponent för att återanvända vid användning av ramverket.""",
		'Please enter values for the following settings.' : 'Ange värden för följande inställningar.',
        'Selected root path: %s' % os.getcwd() : 'Vald rotväg: %s' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Vill du skapa fil pytonik i den här katalogen (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Ange projektnamn, det kommer att användas i projektmappskapande, undvik utrymme medan du skriver',
        'Project name' : 'Projektnamn',
        'Project In-progress, please wait..' : 'Projekt pågår, vänta ..',
        'Do you want to quit (y/n)' : 'Vill du sluta (å / n)'
	 }




lang['tr_TR']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : 'Pytonik MVC Framework %s Başlangıç Dosyası Yapısına hoş geldiniz.' % Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : "Lütfen 'y' veya 'n' girin.",
		"Please enter some text." : 'Lütfen bir metin girin.',
		'Please enter a valid path name.' : 'Lütfen geçerli bir yol adı girin',
		'For more information, visit < https://pytonik.readthedocs.io >.' : 'Daha fazla bilgi için <https://pytonik.readthedocs.io> adresini ziyaret edin.',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """Pytonik, web geliştirmeyi geliştirmek için inşa edilmiş bir python çerçevesidir
         hızlı ve kolay, ayrıca web geliştiricilerinin daha az kodla daha fazla uygulama geliştirmelerine yardımcı olun.
         model görünüm denetleyicisi MVC üzerinde yapılandırılmış etkileyici mimari desen kullanır
         ve çerçeveyi dağıtırken yeniden kullanılacak bileşen demetleri.""",
		'Please enter values for the following settings.' : 'Lütfen aşağıdaki ayarlar için değerler girin.',
        'Selected root path: %s' % os.getcwd() : 'Seçilen kök yolu: %s'  % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : 'Bu dizinde pytonik dosyası oluşturmak istiyor musunuz (y / n)',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : 'Proje adı sağlayın, proje klasörü oluşturmada kullanılacak, yazarken alandan kaçının',
        'Project name' : 'Proje Adı',
        'Project In-progress, please wait..' : 'Proje Devam Ediyor, lütfen bekleyin ..',
        'Do you want to quit (y/n)' : 'Çıkmak istiyor musunuz (y / n)'
	 }


lang['zh_CN']={
        'Welcome to the Pytonik MVC Framework %s Start File Structure.' % Version.VERSION_TEXT : '欢迎使用Pytonik MVC Framework %s 启动文件结构。'% Version.VERSION_TEXT,
		"Please enter either 'y' or 'n'." : '请输入“ y”或“ n”。',
		"Please enter some text." : '请输入一些文字。',
		'Please enter a valid path name.' : '请输入有效的路径名',
		'For more information, visit < https://pytonik.readthedocs.io >.' : '有关更多信息，请访问<https://pytonik.readthedocs.io>',
		"""Pytonik is a python framework built to enhance web development
        fast and easy, also help web developers to build more apps with less codes.
        it uses expressive architectural pattern, structured on model view controller MVC
        and bundles of component to reuse while deploying the framework.""" : """Pytonik是构建用于增强Web开发的python框架
         快速简便的方法，还可以帮助网络开发人员以更少的代码构建更多的应用。
         它使用基于模型视图控制器MVC构建的表达性架构模式
         以及捆绑的组件以在部署框架时重复使用。""",
		'Please enter values for the following settings.' : '请输入以下设置的值。',
        'Selected root path: %s' % os.getcwd() : '选定的根路径：%s' % os.getcwd(),
        'Do you want to create file pytonik in this directory  (y/n)' : '您是否要在此目录中创建文件pytonik（y / n）',
        'Provide project name, it will be use in project folder creation, avoid space while typing' : '提供项目名称，它将在创建项目文件夹时使用，在键入时避免空格',
        'Project name' : '项目名',
        'Project In-progress, please wait..' : '项目进行中，请稍候。',
        'Do you want to quit (y/n)' : '您要退出吗（y / n）'
	 }
